/* vokoscreenNG - A desktop recorder
 * Copyright (C) 2017-2022 Volker Kohaupt
 *
 * Author:
 *      Volker Kohaupt <vkohaupt@volkoh.de>
 *
 * This file is free software; you can redistribute it and/or modify
 * it under the terms of version 2 of the GNU General Public License
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 *
 * --End_License--
 */

#ifndef QVKMAGNIFIERCONTROLLER_H
#define QVKMAGNIFIERCONTROLLER_H

#include "ui_formMainWindow.h"
#include "QvkMagnifier.h"
#include "QvkSpezialSlider.h"

class QvkMagnifierController : public QObject
{
    Q_OBJECT

public:
    QvkMagnifierController( Ui_formMainWindow *ui_mainwindow );
    virtual ~QvkMagnifierController();
    Ui_formMainWindow *ui;

public slots:


private slots:
    void slot_valueChangedRectangle( int value );
    void slot_valueChangedElipse( int value );

    void slot_toolButtonRectangleClicked( bool value );
    void slot_toolButtonElipseClicked( bool value );
    void slot_toolButtonCircleClicked( bool value );

    void  slot_magnifier_on_screen( QScreen *myScreen);
    void slot_label_magnifier_on_screen_clear( bool );


private:
    QvkMagnifier *vkMagnifier;
    QvkSpezialSlider *sliderMagnificationRectangle;
    QvkSpezialSlider *sliderMagnificationElipse;


protected:


signals:


};

#endif
